@@ -56,6 +56,10 @@ _is_legal(a::Fac) = xor(isdefined(a, :fac), isdefined(a, :arr))
 
 _is_dic(a::Fac) = _is_legal(a) && isdefined(a, :fac)
 
+function Base.:(==)(F1::Fac, F2::Fac)
+  error("Equality testing of factorizations is not supported")
+end
+
 @doc raw"""
     unit(a::Fac{T}) -> T
 
