@@ -15,7 +15,7 @@ base_ring_type(::Type{<:PolyRing{T}}) where T<:RingElement = parent_type(T)
 coefficient_ring_type(T::Type{<:PolyRing}) = base_ring_type(T)
 coefficient_ring(R::PolyRing) = base_ring(R)
 
-dense_poly_type(::Type{T}) where T<:RingElement = Generic.Poly{T}
+poly_type(::Type{T}) where T<:RingElement = Generic.Poly{T}
 
 function is_domain_type(::Type{T}) where {S <: RingElement, T <: PolyRingElem{S}}
    return is_domain_type(S)
@@ -223,6 +223,29 @@ function is_monic(a::PolynomialElem)
     return isone(leading_coefficient(a))
 end
 
+@doc raw"""
+    is_unit(f::T) where {T <: PolyRingElem}
+
+Return `true` if the given polynomial over a commutative ring is invertible, otherwise `false`.
+
+# Examples
+```jldoctest
+julia> Z, x = ZZ[:x]
+(Univariate polynomial ring in x over integers, x)
+
+julia> t = x^2+1
+x^2 + 1
+
+julia> is_unit(t)
+false
+
+julia> f = Z(1)
+1
+
+julia> is_unit(f)
+true
+```
+"""
 function is_unit(f::T) where {T <: PolyRingElem}
   # A polynomial over a commutative ring is a unit iff its
   # constant term is a unit and all other coefficients are nilpotent:
