@@ -166,6 +166,7 @@ export compose
 export conj!
 export constant_coefficient
 export content
+export coordinates
 export coprime_base
 export coprime_base_push!
 export crt
@@ -179,8 +180,6 @@ export degree
 export degrees
 export denest
 export dense_matrix_type
-export dense_poly_ring_type
-export dense_poly_type
 export derivative
 export det
 export det_popov
@@ -292,6 +291,8 @@ export iroot
 export is_abelian
 export is_alternating
 export is_associated
+export is_attribute_storing
+export is_attribute_storing_type
 export is_compatible
 export is_constant
 export is_degree
@@ -468,6 +469,8 @@ export pol_length
 export polcoeff
 export poly
 export poly_ring
+export poly_ring_type
+export poly_type
 export polynomial
 export polynomial_ring
 export polynomial_to_power_sums
